@@ -11,17 +11,20 @@ from .uploads_2020_11_01 import Uploads20201101Client
 from .tokens_2021_03_01 import Tokens20210301Client
 from .solicitations_v1 import SolicitationsV1Client
 from .shipping_v1 import ShippingV1Client
+from .shipment_invoicing_v0 import ShipmentInvoicingV0Client
 from .services_v1 import ServicesV1Client
 from .sellers_v1 import SellersV1Client
 from .sales_v1 import SalesV1Client
 from .reports_2021_06_30 import Reports20210630Client
 from .reports_2020_09_04 import Reports20200904Client
+from .product_type_definitions_2020_09_01 import ProductTypeDefinitions20200901Client
 from .product_pricing_v0 import ProductPricingV0Client
 from .product_fees_v0 import ProductFeesV0Client
 from .orders_v0 import OrdersV0Client
 from .notifications_v1 import NotificationsV1Client
 from .messaging_v1 import MessagingV1Client
 from .merchant_fulfillment_v0 import MerchantFulfillmentV0Client
+from .listings_items_2020_09_01 import ListingsItems20200901Client
 from .fulfillment_outbound_2020_07_01 import FulfillmentOutbound20200701Client
 from .fulfillment_inbound_v0 import FulfillmentInboundV0Client
 from .finances_v0 import FinancesV0Client
@@ -37,7 +40,7 @@ from .aplus_content_2020_11_01 import AplusContent20201101Client
 from .marketplaces import MarketPlaces
 from .report_types import ReportType, ReportTypeGroup
 
-version = "1.2.1"
+version = "1.4.0"
 name = "amazon-sp-api-clients"
 author = "Haoyu Pan"
 author_email = "panhaoyu.china@outlook.com"
