@@ -371,7 +371,7 @@ class MessagingV1Client(__BaseClient):
             429: GetMessagingActionsForOrderResponse,
             500: GetMessagingActionsForOrderResponse,
             503: GetMessagingActionsForOrderResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def confirmCustomizationDetails(
         self,
@@ -396,7 +396,7 @@ class MessagingV1Client(__BaseClient):
             429: CreateConfirmCustomizationDetailsResponse,
             500: CreateConfirmCustomizationDetailsResponse,
             503: CreateConfirmCustomizationDetailsResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def createConfirmDeliveryDetails(
         self,
@@ -421,7 +421,7 @@ class MessagingV1Client(__BaseClient):
             429: CreateConfirmDeliveryDetailsResponse,
             500: CreateConfirmDeliveryDetailsResponse,
             503: CreateConfirmDeliveryDetailsResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def createLegalDisclosure(
         self,
@@ -446,7 +446,7 @@ class MessagingV1Client(__BaseClient):
             429: CreateLegalDisclosureResponse,
             500: CreateLegalDisclosureResponse,
             503: CreateLegalDisclosureResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def createNegativeFeedbackRemoval(
         self,
@@ -470,7 +470,7 @@ class MessagingV1Client(__BaseClient):
             429: CreateNegativeFeedbackRemovalResponse,
             500: CreateNegativeFeedbackRemovalResponse,
             503: CreateNegativeFeedbackRemovalResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def createConfirmOrderDetails(
         self,
@@ -495,7 +495,7 @@ class MessagingV1Client(__BaseClient):
             429: CreateConfirmOrderDetailsResponse,
             500: CreateConfirmOrderDetailsResponse,
             503: CreateConfirmOrderDetailsResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def createConfirmServiceDetails(
         self,
@@ -520,7 +520,7 @@ class MessagingV1Client(__BaseClient):
             429: CreateConfirmServiceDetailsResponse,
             500: CreateConfirmServiceDetailsResponse,
             503: CreateConfirmServiceDetailsResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def CreateAmazonMotors(
         self,
@@ -545,7 +545,7 @@ class MessagingV1Client(__BaseClient):
             429: CreateAmazonMotorsResponse,
             500: CreateAmazonMotorsResponse,
             503: CreateAmazonMotorsResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def CreateWarranty(
         self,
@@ -570,7 +570,7 @@ class MessagingV1Client(__BaseClient):
             429: CreateWarrantyResponse,
             500: CreateWarrantyResponse,
             503: CreateWarrantyResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def GetAttributes(
         self,
@@ -594,7 +594,7 @@ class MessagingV1Client(__BaseClient):
             429: GetAttributesResponse,
             500: GetAttributesResponse,
             503: GetAttributesResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def createDigitalAccessKey(
         self,
@@ -619,7 +619,7 @@ class MessagingV1Client(__BaseClient):
             429: CreateDigitalAccessKeyResponse,
             500: CreateDigitalAccessKeyResponse,
             503: CreateDigitalAccessKeyResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def createUnexpectedProblem(
         self,
@@ -644,4 +644,4 @@ class MessagingV1Client(__BaseClient):
             429: CreateUnexpectedProblemResponse,
             500: CreateUnexpectedProblemResponse,
             503: CreateUnexpectedProblemResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
