@@ -256,6 +256,18 @@ class Order:
             self.FulfillmentInstruction: FulfillmentInstruction = FulfillmentInstruction(data["FulfillmentInstruction"])
         else:
             self.FulfillmentInstruction: FulfillmentInstruction = None
+        if "IsISPU" in data:
+            self.IsISPU: bool = bool(data["IsISPU"])
+        else:
+            self.IsISPU: bool = None
+        if "MarketplaceTaxInfo" in data:
+            self.MarketplaceTaxInfo: MarketplaceTaxInfo = MarketplaceTaxInfo(data["MarketplaceTaxInfo"])
+        else:
+            self.MarketplaceTaxInfo: MarketplaceTaxInfo = None
+        if "SellerDisplayName" in data:
+            self.SellerDisplayName: str = str(data["SellerDisplayName"])
+        else:
+            self.SellerDisplayName: str = None
 
 
 class OrderBuyerInfo:
@@ -408,6 +420,18 @@ class BuyerTaxInfo:
             self.TaxClassifications: _List[TaxClassification] = []
 
 
+class MarketplaceTaxInfo:
+    def __init__(self, data):
+        super().__init__()
+        self.data = data
+        if "TaxClassifications" in data:
+            self.TaxClassifications: _List[TaxClassification] = [
+                TaxClassification(datum) for datum in data["TaxClassifications"]
+            ]
+        else:
+            self.TaxClassifications: _List[TaxClassification] = []
+
+
 class TaxClassification:
     def __init__(self, data):
         super().__init__()
@@ -564,6 +588,10 @@ class OrderItem:
             self.IossNumber: str = str(data["IossNumber"])
         else:
             self.IossNumber: str = None
+        if "StoreChainStoreId" in data:
+            self.StoreChainStoreId: str = str(data["StoreChainStoreId"])
+        else:
+            self.StoreChainStoreId: str = None
         if "DeemedResellerCategory" in data:
             self.DeemedResellerCategory: str = str(data["DeemedResellerCategory"])
         else:
@@ -753,6 +781,9 @@ class OrdersV0Client(__BaseClient):
         EasyShipShipmentStatuses: _List[str] = None,
         NextToken: str = None,
         AmazonOrderIds: _List[str] = None,
+        ActualFulfillmentSupplySourceId: str = None,
+        IsISPU: bool = None,
+        StoreChainStoreId: str = None,
     ):
         url = "/orders/v0/orders".format()
         params = {}
@@ -784,6 +815,12 @@ class OrdersV0Client(__BaseClient):
             params["NextToken"] = (NextToken,)
         if AmazonOrderIds is not None:
             params["AmazonOrderIds"] = ",".join(map(str, AmazonOrderIds))
+        if ActualFulfillmentSupplySourceId is not None:
+            params["ActualFulfillmentSupplySourceId"] = (ActualFulfillmentSupplySourceId,)
+        if IsISPU is not None:
+            params["IsISPU"] = (IsISPU,)
+        if StoreChainStoreId is not None:
+            params["StoreChainStoreId"] = (StoreChainStoreId,)
         response = self.request(url, method="GET", params=params)
         return {
             200: GetOrdersResponse,
@@ -793,7 +830,7 @@ class OrdersV0Client(__BaseClient):
             429: GetOrdersResponse,
             500: GetOrdersResponse,
             503: GetOrdersResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def getOrder(
         self,
@@ -812,7 +849,7 @@ class OrdersV0Client(__BaseClient):
             429: GetOrderResponse,
             500: GetOrderResponse,
             503: GetOrderResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def getOrderBuyerInfo(
         self,
@@ -831,7 +868,7 @@ class OrdersV0Client(__BaseClient):
             429: GetOrderBuyerInfoResponse,
             500: GetOrderBuyerInfoResponse,
             503: GetOrderBuyerInfoResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def getOrderAddress(
         self,
@@ -850,7 +887,7 @@ class OrdersV0Client(__BaseClient):
             429: GetOrderAddressResponse,
             500: GetOrderAddressResponse,
             503: GetOrderAddressResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def getOrderItems(
         self,
@@ -872,7 +909,7 @@ class OrdersV0Client(__BaseClient):
             429: GetOrderItemsResponse,
             500: GetOrderItemsResponse,
             503: GetOrderItemsResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def getOrderItemsBuyerInfo(
         self,
@@ -894,4 +931,4 @@ class OrdersV0Client(__BaseClient):
             429: GetOrderItemsBuyerInfoResponse,
             500: GetOrderItemsBuyerInfoResponse,
             503: GetOrderItemsBuyerInfoResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
