@@ -654,7 +654,7 @@ class VendorOrdersV1Client(__BaseClient):
             429: GetPurchaseOrdersResponse,
             500: GetPurchaseOrdersResponse,
             503: GetPurchaseOrdersResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def getPurchaseOrder(
         self,
@@ -675,7 +675,7 @@ class VendorOrdersV1Client(__BaseClient):
             429: GetPurchaseOrderResponse,
             500: GetPurchaseOrderResponse,
             503: GetPurchaseOrderResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def submitAcknowledgement(
         self,
@@ -694,7 +694,7 @@ class VendorOrdersV1Client(__BaseClient):
             429: SubmitAcknowledgementResponse,
             500: SubmitAcknowledgementResponse,
             503: SubmitAcknowledgementResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
 
     def getPurchaseOrdersStatus(
         self,
@@ -747,4 +747,4 @@ class VendorOrdersV1Client(__BaseClient):
             429: GetPurchaseOrdersStatusResponse,
             500: GetPurchaseOrdersStatusResponse,
             503: GetPurchaseOrdersStatusResponse,
-        }[response.status_code](response.json())
+        }[response.status_code](self.__get_response_json(response))
